@@ -17,30 +17,35 @@
 #' cumsum(a)
 #' signif(a, 2)
 Math.units = function(x, ...) {
+  if (.Generic == "sqrt")
+    return(x^0.5)
+  
+  if (.Generic == "sign")
+    return(as.numeric(NextMethod()))
+  
   OK <- switch(.Generic, "abs" = , "sign" = , "floor" = , "ceiling" = , "log" = ,
                "trunc" = , "round" = , "signif" = , "cumsum" = , 
-               "cummax" = , "cummin" = TRUE, FALSE)
+               "cummax" = , "cummin" = , "sqrt" = TRUE, FALSE)
 
-  rad = units(make_unit("rad"))
-  deg = units(make_unit("degree"))
+  rad = units(as_units("rad"))
+  deg = units(as_units("degree"))
   if (!OK && (units(x) == rad || units(x) == deg)) {
     OK <- switch(.Generic, sin =, cos =, tan =, sinpi =, cospi =, tanpi = TRUE, FALSE)
     if (OK) {
-	  units(x) <- "rad" # convert deg -> rad
-	  x <- set_units(x) # result has unit 1
-	}
+      units(x) <- "rad" # convert deg -> rad
+      x <- set_units(x) # result has unit 1
+    }
   }
   if (!OK && units(x) == unitless) {
     OK <- switch(.Generic, asin =, acos =, atan = TRUE, FALSE)
     if (OK)
-	  units(x) <- "rad" # unit of the answer (also unitless)
+      units(x) <- "rad" # unit of the answer (also unitless)
   }
 
   if (!OK) {
     warning(paste("Operation", .Generic, "not meaningful for units"))
-    x = unclass(x)
-    attr(x, "units") = NULL
-    NextMethod(.Generic)
+    x <- drop_units(x)
+    NextMethod()
   } else {
     # nocov start
     # I'm disabling coverage testing for this part because I am not sure
@@ -55,9 +60,11 @@ Math.units = function(x, ...) {
         u = paste0("lb(",units(x),")")
       else
         stop(paste("log with base", dts$base, "not supported"))
-      .as.units(NextMethod(.Generic), units(symbolic_unit(u, check_is_valid = FALSE)))
+      .as.units(NextMethod(), units(symbolic_unit(u, check_is_valid = FALSE)))
       # nocov end
-    } else
+    } else if (.Generic == "sqrt") {
+	  x ^ 0.5
+	} else
       .as.units(NextMethod(.Generic), units(x))
   }
 }
