@@ -5,17 +5,19 @@
 #' set units global options, mostly related how units are printed and plotted
 #' @param ... ignored
 #' @param sep character length two; default \code{c("~", "~")}; space separator between variable and units, and space separator between two different units
-#' @param group character length two; start and end group, may be two empty strings, a parenthesis pair, or square brackets.
-#' @param negative_power logical, default FALSE; should denominators have negative power, or follow a division symbol?
+#' @param group character length two; start and end group, may be two empty strings, a parenthesis pair, or square brackets; default: square brackets.
+#' @param negative_power logical, default \code{FALSE}; should denominators have negative power, or follow a division symbol?
 #' @param parse logical, default \code{TRUE}; should the units be made into an expression (so we get subscripts)? Setting to \code{FALSE} may be useful if \link{parse} fails, e.g. if the unit contains symbols that assume a particular encoding
-#' @param set_units_mode character; either \code{"symbols"} or \code{"standard"}; see \link{set_units}
-#' @param auto_convert_names_to_symbols logical: should names, such as \code{degree_C} be converted to their usual symbol?
+#' @param set_units_mode character; either \code{"symbols"} or \code{"standard"}; see \link{set_units}; default is \code{"symbols"}
+#' @param auto_convert_names_to_symbols logical, default \code{TRUE}: should names, such as \code{degree_C} be converted to their usual symbol?
+#' @param simplify logical, default \code{NA}; simplify units in expressions? 
+#' @details The default \code{NA} value for \code{simplify} means units are not simplified in \link{set_units} or \link{as_units}, but are simplified in arithmetical expressions.
 #' @examples
 #' units_options(sep = c("~~~", "~"), group = c("", "")) # more space, parenthesis
 #' ## set defaults:
 #' units_options(sep = c("~", "~"), group = c("[", "]"), negative_power = FALSE, parse = TRUE)
 #' @export
-units_options = function(..., sep, group, negative_power, parse, set_units_mode, auto_convert_names_to_symbols) {
+units_options = function(..., sep, group, negative_power, parse, set_units_mode, auto_convert_names_to_symbols, simplify) {
 	# op = as.list(units:::.units_options)
 	if (!missing(sep)) {
 	    stopifnot(is.character(sep) && length(sep) == 2)
@@ -41,6 +43,10 @@ units_options = function(..., sep, group, negative_power, parse, set_units_mode,
 		stopifnot(is.logical(auto_convert_names_to_symbols))
 		assign(".units.auto_convert_names_to_symbols", auto_convert_names_to_symbols, envir = .units_options)
 	}
+	if (!missing(simplify)) {
+		stopifnot(is.logical(simplify))
+		assign(".units.simplify", simplify, envir = .units_options)
+	}
 
 	dots = list(...)
 	if (length(dots)) {
@@ -58,4 +64,9 @@ units_options(
 	negative_power = FALSE, 
 	parse = TRUE,
 	set_units_mode = "symbols",
-	auto_convert_names_to_symbols = TRUE) # set defaults
+	auto_convert_names_to_symbols = TRUE,
+	simplify = NA) # set defaults
+
+.units.simplify = function() {
+  get(".units.simplify", envir = .units_options)
+}
